OpenTelemetryGrpcOutputSettings

Struct OpenTelemetryGrpcOutputSettings 

pub struct OpenTelemetryGrpcOutputSettings {
    pub endpoint_url: String,
    pub request_timeout_seconds: u64,
    pub num_tasks: usize,
    pub max_batch_size: usize,
}
Available on (crate features logging or metrics or tracing or memory-profiling or telemetry-server) and crate feature telemetry-otlp-grpc only.
OpenTelemetry output settings.

Fields

endpoint_url: String

The URL of the endpoint that will receive the telemetry data.

Default

Default value is the standard gRPC endpoints URL: http://localhost:4317. See: https://opentelemetry.io/docs/languages/sdk-configuration/otlp-exporter/#otel_exporter_otlp_endpoint

request_timeout_seconds: u64

Output request timeout in seconds.

An error will be logged (if logging is enabled for the service) if timeout is reached.

Default

Default value is 10 seconds.

num_tasks: usize

Number of concurrent tasks to spawn for output.

A higher number means more spans can be collected in parallel in a multi-threaded runtime. All tasks share a gRPC channel, but can send RPCs in parallel. The default is 1 task.

max_batch_size: usize

Maximum number of entries to be batched together and sent in one request.

Default

Default value is 512.